@@ -252,7 +252,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         if temp != None and temp !="":
             self.category = temp 
         else:
-            self.category = "All"
+            self.category = ""
         temp = self.client.get_int(NUM)
         if temp == 0:
             self.count = 2
@@ -332,7 +332,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
                     button = DiggItemWidget(item)
                     self.vbox.add(button)
             self.show_all()
-            self.client.set_string(KEY, self.category)
+            self.client.set_string(CATGR, self.category)
             title = self.category
             title = title.replace("_", "&")
             if title == "":
